{% extends "shopit/base.html" %}
{% load i18n shopit_tags %}

{% block page_title %}{% trans "Cart" %}{% endblock %}

{% block content %}
  {% if cart_items %}
    {% cart %}
    <div class="mt-2 float-right">
      <a href="{% url 'shopit-cart-empty' %}" class="btn btn-danger">{% trans "Empty the cart" %}</a>
      <a href="{% url 'shopit-checkout' %}" class="btn btn-success">{% trans "Proceed to checkout" %}</a>
    </div>
  {% else %}
    <p>{% trans "Cart is empty." %}</p>
  {% endif %}
{% endblock %}
