# -*- coding: utf-8 -*-
# Generated by Django 1.11.10 on 2018-04-04 10:19
from __future__ import unicode_literals

from decimal import Decimal
from django.db import migrations, models
import shop.money.fields


class Migration(migrations.Migration):

    dependencies = [
        ('shopit', '0010_add_placeholder_fields_to_categorization_models'),
    ]

    operations = [
        migrations.AlterField(
            model_name='modifier',
            name='amount',
            field=shop.money.fields.MoneyField(default=0, help_text='Amount that should be added. Can be negative.', verbose_name='Amount'),
        ),
        migrations.AlterField(
            model_name='product',
            name='_unit_price',
            field=shop.money.fields.MoneyField(default=0, help_text='For variants leave empty to use the Group price.', verbose_name='Unit price'),
        ),
    ]
