{% extends "shopit/base.html" %}
{% load i18n %}

{% block page_title %}{% trans "Account register" %}{% endblock %}

{% block content %}
  <form action="{% url 'shopit-account-register' %}" method="POST" data-ajax-success="{% url 'shopit-account-detail' %}" novalidate>
    {% csrf_token %}
    {{ form.as_p }}
    <button class="btn btn-primary">{% trans "Register" %}</button>
  </form>
{% endblock %}
