{% extends "shopit/base.html" %}
{% load i18n %}

{% block page_title %}{% if validlink %}{% blocktrans %}New password for '{{ user_name }}'{% endblocktrans %}{% else %}{% trans "Link is invalid" %}{% endif %}{% endblock %}

{% block content %}
  {% if validlink %}
    <form action="{{ request.path }}" method="POST" data-ajax-success="{% url 'shopit-account-login' %}" novalidate>
      {% csrf_token %}
      {{ form.as_p }}
      <button class="btn btn-primary">{% trans "Reset password" %}</button>
    </form>
  {% else %}
    <p>{% trans "Please try again." %}</p>
  {% endif %}
{% endblock %}
