{% extends "shopit/account/account_detail.html" %}
{% load i18n shopit_tags %}

{% block page_title %}{{ block.super }} &bull; {% trans "Order" %} #{{ order }}{% endblock %}

{% block body %}
  {% order order %}
{% endblock %}
