{% extends "shopit/base.html" %}
{% load i18n %}

{% block page_title %}{% trans "Account login" %}{% endblock %}

{% block content %}
  <form action="{% url 'shopit-account-login' %}" method="POST" data-ajax-success="{% url 'shopit-account-detail' %}" novalidate>
    {% csrf_token %}
    {{ form.as_p }}
    <p><a href="{% url 'shopit-account-reset' %}">{% trans "Forgot password?" %}</a></p>
    <button class="btn btn-primary">{% trans "Login" %}</button> {% trans "or" %}
    <a href="{% url 'shopit-account-register' %}" class="btn btn-secondary">{% trans "Register" %}</a>
  </form>
{% endblock %}
