# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-06-06 13:02
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('shopit', '0006_rename_caption_description'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='reviewtranslation',
            unique_together=set([]),
        ),
        migrations.RemoveField(
            model_name='reviewtranslation',
            name='master',
        ),
        migrations.AddField(
            model_name='review',
            name='language',
            field=models.CharField(choices=[('en', 'English')], default='en', max_length=2, verbose_name='Language'),
        ),
        migrations.AddField(
            model_name='review',
            name='name',
            field=models.CharField(blank=True, max_length=128, verbose_name='Name'),
        ),
        migrations.AddField(
            model_name='review',
            name='text',
            field=models.TextField(default='', max_length=1024, verbose_name='Text'),
            preserve_default=False,
        ),
        migrations.DeleteModel(
            name='ReviewTranslation',
        ),
    ]
