# -*- coding: utf-8 -*-
# Generated by Django 1.11.10 on 2018-04-10 09:02
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('shopit', '0011_set_default_price_to_zero'),
    ]

    operations = [
        migrations.AddField(
            model_name='flag',
            name='template',
            field=models.CharField(blank=True, help_text='You can specify a template for rendering this flag or leave it empty for the default look.', max_length=255, null=True, verbose_name='Template'),
        ),
    ]
