# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-07-17 10:07
from __future__ import unicode_literals

import cms.models.fields
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('cms', '__first__'),
        ('shopit', '0009_add_max_and_num_uses_to_discount_code'),
    ]

    operations = [
        migrations.AddField(
            model_name='brand',
            name='content',
            field=cms.models.fields.PlaceholderField(editable=False, null=True, on_delete=django.db.models.deletion.CASCADE, slotname='shopit_brand_content', to='cms.Placeholder'),
        ),
        migrations.AddField(
            model_name='category',
            name='content',
            field=cms.models.fields.PlaceholderField(editable=False, null=True, on_delete=django.db.models.deletion.CASCADE, slotname='shopit_category_content', to='cms.Placeholder'),
        ),
        migrations.AddField(
            model_name='manufacturer',
            name='content',
            field=cms.models.fields.PlaceholderField(editable=False, null=True, on_delete=django.db.models.deletion.CASCADE, slotname='shopit_manufacturer_content', to='cms.Placeholder'),
        ),
    ]
