# -*- coding: utf-8 -*-
# Generated by Django 1.9.9 on 2016-12-19 13:33
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion
import mptt.fields


class Migration(migrations.Migration):

    dependencies = [
        ('shopit', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='flag',
            options={'ordering': ['tree_id', 'lft'], 'verbose_name': 'Flag', 'verbose_name_plural': 'Flags'},
        ),
        migrations.RemoveField(
            model_name='flag',
            name='order',
        ),
        migrations.AddField(
            model_name='flag',
            name='level',
            field=models.PositiveIntegerField(db_index=True, default=0, editable=False),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='flag',
            name='lft',
            field=models.PositiveIntegerField(db_index=True, default=0, editable=False),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='flag',
            name='parent',
            field=mptt.fields.TreeForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='children', to='shopit.Flag', verbose_name='Parent'),
        ),
        migrations.AddField(
            model_name='flag',
            name='rght',
            field=models.PositiveIntegerField(db_index=True, default=0, editable=False),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='flag',
            name='tree_id',
            field=models.PositiveIntegerField(db_index=True, default=0, editable=False),
            preserve_default=False,
        ),
    ]
